@@ -568,14 +568,12 @@ mod_upload_server <- function(input, output, session, parent_session){
         qtlpoly_fitted.mod = input$qtlpoly_fitted.mod))
     } else if(values$upload_state_diaQTL == "uploaded"){
       validate(
-        need(!is.null(input$qtlpoly_data), "Upload diaQTL data file before submit"),
-        need(!is.null(input$qtlpoly_remim.mod), "Upload diaQTL scan1 file before submit"),
-        need(!is.null(input$qtlpoly_est.effects), "Upload diaQTL scan1.summaries file before submit"),
-        need(!is.null(input$qtlpoly_fitted.mod), "Upload diaQTL fitQTL file before submit"),
-        need(!is.null(input$qtlpoly_fitted.mod), "Upload diaQTL BayesCI file before submit")
+        need(!is.null(input$diaQTL_scan1), "Upload diaQTL scan1 file before submit"),
+        need(!is.null(input$diaQTL_scan1.summaries), "Upload diaQTL scan1.summaries file before submit"),
+        need(!is.null(input$diaQTL_fitQTL), "Upload diaQTL fitQTL file before submit"),
+        need(!is.null(input$diaQTL_BayesCI), "Upload diaQTL BayesCI file before submit")
       )
       return(list(
-        diaQTL_data = input$diaQTL_data,
         diaQTL_scan1 = input$diaQTL_scan1,
         diaQTL_scan1.summaries = input$diaQTL_scan1.summaries,
         diaQTL_fitQTL = input$diaQTL_fitQTL,
@@ -604,7 +602,7 @@ mod_upload_server <- function(input, output, session, parent_session){
         return(NULL)
       } else if(values$upload_state_genome == "uploaded"){
         validate(
-          need(!is.null(input$fasta), "Upload reference genome (FASTA) file before submit.")
+          need(!is.null(input$fasta) | !is.null(input$fasta_server), "Upload reference genome (FASTA) file before submit.")
         )
         return(list(fasta = input$fasta,
                     fasta_server = input$fasta_server,
@@ -672,7 +670,7 @@ mod_upload_server <- function(input, output, session, parent_session){
       } else if (values$upload_state_viewpoly == 'reset') {
         return(NULL)
       } else if(values$upload_state_viewpoly == "uploaded"){
-        if(!is.null(input$viewpoly_input) | !is.null(input$viewpoly_env)){ 
+        if(is.null(input$viewpoly_input) & is.null(input$viewpoly_env)){ 
           warning("Upload a viewpoly dataset or select one available in your R environment before submit.")
           viewpoly.obj <- NULL
         } else if(!is.null(input$viewpoly_input)){
@@ -685,296 +683,298 @@ mod_upload_server <- function(input, output, session, parent_session){
       } 
     })
   })
-
-loadMap_custom = reactive({
-  if(!(is.null(input_map()$dosages) & is.null(input_map()$phases) & is.null(input_map()$genetic_map))){
-    req(input_map()$dosages, input_map()$phases, input_map()$genetic_map)
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.5, detail = paste("Uploading custom map data..."))
-      prepare_map_custom_files(input_map()$dosages,
-                               input_map()$phases,
-                               input_map()$genetic_map)
-    })
-  } else NULL
-})
-
-loadMap_mappoly =  reactive({
   
-  if(!is.null(input_map()$mappoly_in)){
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.3, detail = paste("Uploading MAPpoly data..."))
-      prepare_MAPpoly(input_map()$mappoly_in)
-    })
-  } else NULL
-})
-
-loadMap_polymapR =  reactive({
-  if(!(is.null(input_map()$polymapR.dataset) & 
-       is.null(input_map()$polymapR.map))) {
-    req(input_map()$polymapR.dataset, input_map()$polymapR.map)
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.1, detail = paste("Uploading polymapR data..."))
-      prepare_polymapR(input_map()$polymapR.dataset, input_map()$polymapR.map, 
-                       input$input.type, as.numeric(input$ploidy))
-    })
-  } else NULL
-})
-
-loadQTL_custom = reactive({
-  if(!(is.null(input_qtl()$selected_mks) & 
-       is.null(input_qtl()$qtl_info) & 
-       is.null(input_qtl()$blups) & 
-       is.null(input_qtl()$beta.hat) & 
-       is.null(input_qtl()$profile) & 
-       is.null(input_qtl()$effects) & 
-       is.null(input_qtl()$probs))) {
-    req(input_qtl()$selected_mks, input_qtl()$qtl_info, input_qtl()$blups,
-        input_qtl()$beta.hat, input_qtl()$profile, input_qtl()$effects,
-        input_qtl()$probs)
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.5, detail = paste("Uploading custom QTL data..."))
-      prepare_qtl_custom_files(input_qtl()$selected_mks,
-                               input_qtl()$qtl_info,
-                               input_qtl()$blups,
-                               input_qtl()$beta.hat,
-                               input_qtl()$profile,
-                               input_qtl()$effects,
-                               input_qtl()$probs)
-    })
-  } else NULL
-})
-
-loadQTL_qtlpoly = reactive({
-  if(!(is.null(input_qtl()$qtlpoly_data) & 
-       is.null(input_qtl()$qtlpoly_remim.mod) &
-       is.null(input_qtl()$qtlpoly_est.effects) &
-       is.null(input_qtl()$qtlpoly_fitted.mod))) {
-    
-    req(input_qtl()$qtlpoly_data, 
-        input_qtl()$qtlpoly_remim.mod,
-        input_qtl()$qtlpoly_est.effects,
-        input_qtl()$qtlpoly_fitted.mod)
-    
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.3, detail = paste("Uploading QTLpoly data..."))
-      prepare_QTLpoly(input_qtl()$qtlpoly_data,
-                      input_qtl()$qtlpoly_remim.mod,
-                      input_qtl()$qtlpoly_est.effects,
-                      input_qtl()$qtlpoly_fitted.mod)
-    })
-  } else NULL
-})
-
-loadQTL_diaQTL = reactive({
-  if(!(is.null(input_qtl()$diaQTL_scan1) &
-       is.null(input_qtl()$diaQTL_scan1.summaries) &
-       is.null(input_qtl()$diaQTL_fitQTL) &
-       is.null(input_qtl()$diaQTL_BayesCI))) {
-    
-    req(input_qtl()$diaQTL_scan1,
-        input_qtl()$diaQTL_scan1.summaries,
-        input_qtl()$diaQTL_fitQTL,
-        input_qtl()$diaQTL_BayesCI)
-    
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.3, detail = paste("Uploading diaQTL data..."))
-      prepare_diaQTL(input_qtl()$diaQTL_scan1,
-                     input_qtl()$diaQTL_scan1.summaries,
-                     input_qtl()$diaQTL_fitQTL,
-                     input_qtl()$diaQTL_BayesCI)
-    })
-  } else NULL
-})
-
-loadQTL_polyqtlR = reactive({
-  if(!(is.null(input_qtl()$polyqtlR_QTLscan_list) & 
-       is.null(input_qtl()$polyqtlR_qtl_info) &
-       is.null(input_qtl()$polyqtlR_effects))) {
-    
-    req(input_qtl()$polyqtlR_QTLscan_list,
-        input_qtl()$polyqtlR_qtl_info,
-        input_qtl()$polyqtlR_effects)
-    
-    withProgress(message = 'Working:', value = 0, {
-      incProgress(0.3, detail = paste("Uploading polyqtlR data..."))
-      prepare_polyqtlR(input_qtl()$polyqtlR_QTLscan_list,
-                       input_qtl()$polyqtlR_qtl_info,
-                       input_qtl()$polyqtlR_effects)
-    })
-  } else NULL
-})
-
-temp_dir <- reactive(tempdir())
-
-loadJBrowse_fasta = reactive({
-  withProgress(message = 'Working:', value = 0, {
-    incProgress(0.1, detail = paste("Uploading fasta path..."))
-    if(!is.null(input_genome()$fasta) & !is.null(loadMap())){
-      # keep fasta name
-      for(i in 1:length(input_genome()$fasta$datapath)){
-        file.rename(input_genome()$fasta$datapath[i], 
-                    file.path(temp_dir(), input_genome()$fasta$name[i]))
-      }
-      file.path(temp_dir(), input_genome()$fasta$name[1]) 
-    } else if(!is.null(input_genome()$fasta_server) & !is.null(loadMap())) {
-      input_genome()$fasta_server
-    } else if(!is.null(input_genome()$fasta) | !is.null(input_genome()$fasta_server)) {
-      warning("Load map data first to use this feature.")
+  loadMap_custom = reactive({
+    if(!(is.null(input_map()$dosages) & is.null(input_map()$phases) & is.null(input_map()$genetic_map))){
+      req(input_map()$dosages, input_map()$phases, input_map()$genetic_map)
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.5, detail = paste("Uploading custom map data..."))
+        prepare_map_custom_files(input_map()$dosages,
+                                 input_map()$phases,
+                                 input_map()$genetic_map)
+      })
     } else NULL
   })
-})
-
-loadJBrowse_gff3 = reactive({
-  withProgress(message = 'Working:', value = 0, {
-    incProgress(0.1, detail = paste("Uploading gff3 path..."))
-    if(!is.null(input_genome()$gff3)){
-      for(i in 1:length(input_genome()$gff3$datapath)){
-        file.rename(input_genome()$gff3$datapath[i], 
-                    file.path(temp_dir(), input_genome()$gff3$name[i]))
-      }
-      file.path(temp_dir(), input_genome()$gff3$name[1]) 
-    } else if(!is.null(input_genome()$gff3_server)) { 
-      input_genome()$gff3_server
+  
+  loadMap_mappoly =  reactive({
+    
+    if(!is.null(input_map()$mappoly_in)){
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.3, detail = paste("Uploading MAPpoly data..."))
+        prepare_MAPpoly(input_map()$mappoly_in)
+      })
     } else NULL
   })
-})
-
-loadJBrowse_vcf = reactive({
-  withProgress(message = 'Working:', value = 0, {
-    incProgress(0.1, detail = paste("Uploading VCF path..."))
-    if(!is.null(input_genome()$vcf)) {
-      for(i in 1:length(input_genome()$vcf$datapath)){
-        file.rename(input_genome()$vcf$datapath[i], 
-                    file.path(temp_dir(), input_genome()$vcf$name[i]))
-      }
-      file.path(temp_dir(), input_genome()$vcf$name[1]) 
-    } else if(!is.null(input_genome()$vcf_server)) {
-      input_genome()$vcf_server
+  
+  loadMap_polymapR =  reactive({
+    if(!(is.null(input_map()$polymapR.dataset) & 
+         is.null(input_map()$polymapR.map))) {
+      req(input_map()$polymapR.dataset, input_map()$polymapR.map)
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.1, detail = paste("Uploading polymapR data..."))
+        prepare_polymapR(input_map()$polymapR.dataset, input_map()$polymapR.map, 
+                         input$input.type, as.numeric(input$ploidy))
+      })
     } else NULL
   })
-})
-
-loadJBrowse_align = reactive({
-  withProgress(message = 'Working:', value = 0, {
-    incProgress(0.1, detail = paste("Uploading BAM or CRAM alignment data path..."))
-    if(!is.null(input_genome()$align)) {
-      for(i in 1:length(input_genome()$align$datapath)){
-        file.rename(input_genome()$align$datapath[i], 
-                    file.path(temp_dir(), input_genome()$align$name[i]))
-      }
-      file.path(temp_dir(), input_genome()$align$name[1]) 
-    } else if(!is.null(input_genome()$align_server)) {
-      input_genome()$align_server
+  
+  loadQTL_custom = reactive({
+    if(!(is.null(input_qtl()$selected_mks) & 
+         is.null(input_qtl()$qtl_info) & 
+         is.null(input_qtl()$blups) & 
+         is.null(input_qtl()$beta.hat) & 
+         is.null(input_qtl()$profile) & 
+         is.null(input_qtl()$effects) & 
+         is.null(input_qtl()$probs))) {
+      req(input_qtl()$selected_mks, input_qtl()$qtl_info, input_qtl()$blups,
+          input_qtl()$beta.hat, input_qtl()$profile, input_qtl()$effects,
+          input_qtl()$probs)
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.5, detail = paste("Uploading custom QTL data..."))
+        prepare_qtl_custom_files(input_qtl()$selected_mks,
+                                 input_qtl()$qtl_info,
+                                 input_qtl()$blups,
+                                 input_qtl()$beta.hat,
+                                 input_qtl()$profile,
+                                 input_qtl()$effects,
+                                 input_qtl()$probs)
+      })
     } else NULL
   })
-})
-
-loadJBrowse_wig = reactive({
-  withProgress(message = 'Working:', value = 0, {
-    incProgress(0.1, detail = paste("Uploading bigWig data path..."))
-    if(!is.null(input_genome()$wig)) {
-      for(i in 1:length(input_genome()$wig$datapath)){
-        file.rename(input_genome()$wig$datapath[i], 
-                    file.path(temp_dir(), input_genome()$wig$name[i]))
-      }
-      file.path(temp_dir(), input_genome()$wig$name[1]) 
-    } else if(!is.null(input_genome()$wig_server)) {
-      input_genome()$wig_server
+  
+  loadQTL_qtlpoly = reactive({
+    if(!(is.null(input_qtl()$qtlpoly_data) & 
+         is.null(input_qtl()$qtlpoly_remim.mod) &
+         is.null(input_qtl()$qtlpoly_est.effects) &
+         is.null(input_qtl()$qtlpoly_fitted.mod))) {
+      
+      req(input_qtl()$qtlpoly_data, 
+          input_qtl()$qtlpoly_remim.mod,
+          input_qtl()$qtlpoly_est.effects,
+          input_qtl()$qtlpoly_fitted.mod)
+      
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.3, detail = paste("Uploading QTLpoly data..."))
+        prepare_QTLpoly(input_qtl()$qtlpoly_data,
+                        input_qtl()$qtlpoly_remim.mod,
+                        input_qtl()$qtlpoly_est.effects,
+                        input_qtl()$qtlpoly_fitted.mod)
+      })
     } else NULL
   })
-})
-
-loadMap = reactive({
-  if(is.null(loadExample()) & 
-     is.null(loadMap_custom()) & 
-     is.null(loadMap_mappoly()) &
-     is.null(loadMap_polymapR()) &
-     is.null(loadViewpoly())){
-    warning("Select one of the options in `upload` session")
-    return(NULL)
-  } else if(!is.null(loadViewpoly())){
-    return(loadViewpoly()$map)
-  } else if(!is.null(loadMap_custom())){
-    return(loadMap_custom())
-  } else if(!is.null(loadMap_mappoly())){
-    return(loadMap_mappoly())
-  } else if(!is.null(loadMap_polymapR())){
-    return(loadMap_polymapR())
-  } else if(!is.null(loadExample())){
-    return(loadExample()$map)
-  }
-})
-
-loadQTL = reactive({
-  if(is.null(loadExample()) & 
-     is.null(loadQTL_custom()) & 
-     is.null(loadQTL_qtlpoly()) & 
-     is.null(loadQTL_diaQTL()) &
-     is.null(loadQTL_polyqtlR()) &
-     is.null(loadViewpoly())){
-    warning("Select one of the options in `upload` session")
-    return(NULL)
-  } else if(!is.null(loadViewpoly())){
-    return(loadViewpoly()$qtl)
-  } else if(!is.null(loadQTL_custom())){
-    return(loadQTL_custom())
-  } else if(!is.null(loadQTL_qtlpoly())){
-    return(loadQTL_qtlpoly())
-  } else if(!is.null(loadQTL_diaQTL())){
-    return(loadQTL_diaQTL())
-  } else if(!is.null(loadQTL_polyqtlR())){
-    return(loadQTL_polyqtlR())
-  } else if(!is.null(loadExample())){
-    return(loadExample()$qtl)
-  }
-})
-
-observe({
-  if (!is.null(loadMap()) | !is.null(loadQTL())) {
-    Sys.sleep(1)
-    # enable the download button
-    shinyjs::enable("export_viewpoly")
-  } else {
-    shinyjs::disable("export_viewpoly")
-  }
-})
-
-output$export_viewpoly <- downloadHandler(
-  filename = function() {
-    paste0("viewpoly.RData")
-  },
-  content = function(file) {
+  
+  loadQTL_diaQTL = reactive({
+    if(!(is.null(input_qtl()$diaQTL_scan1) &
+         is.null(input_qtl()$diaQTL_scan1.summaries) &
+         is.null(input_qtl()$diaQTL_fitQTL) &
+         is.null(input_qtl()$diaQTL_BayesCI))) {
+      
+      req(input_qtl()$diaQTL_scan1,
+          input_qtl()$diaQTL_scan1.summaries,
+          input_qtl()$diaQTL_fitQTL,
+          input_qtl()$diaQTL_BayesCI)
+      
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.3, detail = paste("Uploading diaQTL data..."))
+        prepare_diaQTL(input_qtl()$diaQTL_scan1,
+                       input_qtl()$diaQTL_scan1.summaries,
+                       input_qtl()$diaQTL_fitQTL,
+                       input_qtl()$diaQTL_BayesCI)
+      })
+    } else NULL
+  })
+  
+  loadQTL_polyqtlR = reactive({
+    if(!(is.null(input_qtl()$polyqtlR_QTLscan_list) & 
+         is.null(input_qtl()$polyqtlR_qtl_info) &
+         is.null(input_qtl()$polyqtlR_effects))) {
+      
+      req(input_qtl()$polyqtlR_QTLscan_list,
+          input_qtl()$polyqtlR_qtl_info,
+          input_qtl()$polyqtlR_effects)
+      
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.3, detail = paste("Uploading polyqtlR data..."))
+        prepare_polyqtlR(input_qtl()$polyqtlR_QTLscan_list,
+                         input_qtl()$polyqtlR_qtl_info,
+                         input_qtl()$polyqtlR_effects)
+      })
+    } else NULL
+  })
+  
+  temp_dir <- reactive(tempdir())
+  
+  loadJBrowse_fasta = reactive({
     withProgress(message = 'Working:', value = 0, {
-      incProgress(0.1, detail = paste("Saving viewpoly object..."))
-      validate(
-        need(!is.null(loadMap()) | !is.null(loadQTL()), "For exporting VIEWpoly dataset it is required to load 
+      incProgress(0.1, detail = paste("Uploading fasta path..."))
+      if(!is.null(input_genome()$fasta) & !is.null(loadMap())){
+        # keep fasta name
+        for(i in 1:length(input_genome()$fasta$datapath)){
+          file.rename(input_genome()$fasta$datapath[i], 
+                      file.path(temp_dir(), input_genome()$fasta$name[i]))
+        }
+        file.path(temp_dir(), input_genome()$fasta$name[1]) 
+      } else if(!is.null(input_genome()$fasta_server) & !is.null(loadMap())) {
+        input_genome()$fasta_server
+      } else if(!is.null(input_genome()$fasta) | !is.null(input_genome()$fasta_server)) {
+        warning("Load map data first to use this feature.")
+      } else if(!is.null(loadExample())){
+        loadExample()$fasta
+      } else NULL
+    })
+  })
+  
+  loadJBrowse_gff3 = reactive({
+    withProgress(message = 'Working:', value = 0, {
+      incProgress(0.1, detail = paste("Uploading gff3 path..."))
+      if(!is.null(input_genome()$gff3)){
+        for(i in 1:length(input_genome()$gff3$datapath)){
+          file.rename(input_genome()$gff3$datapath[i], 
+                      file.path(temp_dir(), input_genome()$gff3$name[i]))
+        }
+        file.path(temp_dir(), input_genome()$gff3$name[1]) 
+      } else if(!is.null(input_genome()$gff3_server)) { 
+        input_genome()$gff3_server
+      } else if(!is.null(loadExample())){
+        loadExample()$gff3
+      } else NULL
+    })
+  })
+  
+  loadJBrowse_vcf = reactive({
+    withProgress(message = 'Working:', value = 0, {
+      incProgress(0.1, detail = paste("Uploading VCF path..."))
+      if(!is.null(input_genome()$vcf)) {
+        for(i in 1:length(input_genome()$vcf$datapath)){
+          file.rename(input_genome()$vcf$datapath[i], 
+                      file.path(temp_dir(), input_genome()$vcf$name[i]))
+        }
+        file.path(temp_dir(), input_genome()$vcf$name[1]) 
+      } else if(!is.null(input_genome()$vcf_server)) {
+        input_genome()$vcf_server
+      } else NULL
+    })
+  })
+  
+  loadJBrowse_align = reactive({
+    withProgress(message = 'Working:', value = 0, {
+      incProgress(0.1, detail = paste("Uploading BAM or CRAM alignment data path..."))
+      if(!is.null(input_genome()$align)) {
+        for(i in 1:length(input_genome()$align$datapath)){
+          file.rename(input_genome()$align$datapath[i], 
+                      file.path(temp_dir(), input_genome()$align$name[i]))
+        }
+        file.path(temp_dir(), input_genome()$align$name[1]) 
+      } else if(!is.null(input_genome()$align_server)) {
+        input_genome()$align_server
+      } else NULL
+    })
+  })
+  
+  loadJBrowse_wig = reactive({
+    withProgress(message = 'Working:', value = 0, {
+      incProgress(0.1, detail = paste("Uploading bigWig data path..."))
+      if(!is.null(input_genome()$wig)) {
+        for(i in 1:length(input_genome()$wig$datapath)){
+          file.rename(input_genome()$wig$datapath[i], 
+                      file.path(temp_dir(), input_genome()$wig$name[i]))
+        }
+        file.path(temp_dir(), input_genome()$wig$name[1]) 
+      } else if(!is.null(input_genome()$wig_server)) {
+        input_genome()$wig_server
+      } else NULL
+    })
+  })
+  
+  loadMap = reactive({
+    if(is.null(loadExample()) & 
+       is.null(loadMap_custom()) & 
+       is.null(loadMap_mappoly()) &
+       is.null(loadMap_polymapR()) &
+       is.null(loadViewpoly())){
+      warning("Select one of the options in `upload` session")
+      return(NULL)
+    } else if(!is.null(loadViewpoly())){
+      return(loadViewpoly()$map)
+    } else if(!is.null(loadMap_custom())){
+      return(loadMap_custom())
+    } else if(!is.null(loadMap_mappoly())){
+      return(loadMap_mappoly())
+    } else if(!is.null(loadMap_polymapR())){
+      return(loadMap_polymapR())
+    } else if(!is.null(loadExample())){
+      return(loadExample()$map)
+    }
+  })
+  
+  loadQTL = reactive({
+    if(is.null(loadExample()) & 
+       is.null(loadQTL_custom()) & 
+       is.null(loadQTL_qtlpoly()) & 
+       is.null(loadQTL_diaQTL()) &
+       is.null(loadQTL_polyqtlR()) &
+       is.null(loadViewpoly())){
+      warning("Select one of the options in `upload` session")
+      return(NULL)
+    } else if(!is.null(loadViewpoly())){
+      return(loadViewpoly()$qtl)
+    } else if(!is.null(loadQTL_custom())){
+      return(loadQTL_custom())
+    } else if(!is.null(loadQTL_qtlpoly())){
+      return(loadQTL_qtlpoly())
+    } else if(!is.null(loadQTL_diaQTL())){
+      return(loadQTL_diaQTL())
+    } else if(!is.null(loadQTL_polyqtlR())){
+      return(loadQTL_polyqtlR())
+    } else if(!is.null(loadExample())){
+      return(loadExample()$qtl)
+    }
+  })
+  
+  observe({
+    if (!is.null(loadMap()) | !is.null(loadQTL())) {
+      Sys.sleep(1)
+      # enable the download button
+      shinyjs::enable("export_viewpoly")
+    } else {
+      shinyjs::disable("export_viewpoly")
+    }
+  })
+  
+  output$export_viewpoly <- downloadHandler(
+    filename = function() {
+      paste0("viewpoly.RData")
+    },
+    content = function(file) {
+      withProgress(message = 'Working:', value = 0, {
+        incProgress(0.1, detail = paste("Saving viewpoly object..."))
+        validate(
+          need(!is.null(loadMap()) | !is.null(loadQTL()), "For exporting VIEWpoly dataset it is required to load 
                linkage map or QTL data in the above boxes."),
-      )
-      obj <- structure(list(map = loadMap(), 
-                            qtl = loadQTL(), 
-                            fasta = NULL, # It would save only the temporary path
-                            gff3 = NULL, 
-                            vcf = NULL,
-                            align = NULL,
-                            wig = NULL,
-                            version = packageVersion("viewpoly")), 
-                       class = "viewpoly")
-      assign(input$data.name, obj)
-      incProgress(0.5, detail = paste("Saving viewpoly object..."))
-    })
-    save(list = input$data.name, file = file)
-  }
-)  
-
-return(list(loadMap = reactive(loadMap()), 
-            loadQTL = reactive(loadQTL()), 
-            loadJBrowse_fasta = reactive(loadJBrowse_fasta()), 
-            loadJBrowse_gff3 = reactive(loadJBrowse_gff3()), 
-            loadJBrowse_vcf = reactive(loadJBrowse_vcf()),
-            loadJBrowse_align = reactive(loadJBrowse_align()),
-            loadJBrowse_wig = reactive(loadJBrowse_wig()),
-            loadExample = reactive(loadExample())
-))
+        )
+        obj <- structure(list(map = loadMap(), 
+                              qtl = loadQTL(), 
+                              fasta = NULL, # It would save only the temporary path
+                              gff3 = NULL, 
+                              vcf = NULL,
+                              align = NULL,
+                              wig = NULL,
+                              version = packageVersion("viewpoly")), 
+                         class = "viewpoly")
+        assign(input$data.name, obj)
+        incProgress(0.5, detail = paste("Saving viewpoly object..."))
+      })
+      save(list = input$data.name, file = file)
+    }
+  )  
+  
+  return(list(loadMap = reactive(loadMap()), 
+              loadQTL = reactive(loadQTL()), 
+              loadJBrowse_fasta = reactive(loadJBrowse_fasta()), 
+              loadJBrowse_gff3 = reactive(loadJBrowse_gff3()), 
+              loadJBrowse_vcf = reactive(loadJBrowse_vcf()),
+              loadJBrowse_align = reactive(loadJBrowse_align()),
+              loadJBrowse_wig = reactive(loadJBrowse_wig())))
 }
 
 ## To be copied in the UI
